# InstanceLib

An abstract interface for datasets.
This library is hosted on [https://git.science.uu.nl/mpbron-phd/instancelib](https://git.science.uu.nl/mpbron-phd/instancelib) and available for usage according to the GNU LGPL v3 license. 

# Installation
You can install this Python package from PyPI by using the following command `pip install instancelib`.

# Usage
In the repo, see `usage.py` for examples on how to use this library. 